@@ -47,8 +47,8 @@ class ChipmunkDb():
         retdata = res.json()
         return retdata["data"]
 
-    def save_document(self, directory, document, data):
-        res = requests.post(url=self.getHostAndPort()+"/directory/"+directory+"/"+document, data=json.dumps({"data": data}))
+    def save_document(self, directory, document, data, type="single"):
+        res = requests.post(url=self.getHostAndPort()+"/directory/"+directory+"/"+document, data=json.dumps({"data": data, "type": type}))
         retdata = res.json()
         if "error" in data:
             return None
